summaryrefslogtreecommitdiff
path: root/nuttx/configs/stm3220g-eval/src/up_buttons.c
diff options
context:
space:
mode:
Diffstat (limited to 'nuttx/configs/stm3220g-eval/src/up_buttons.c')
-rw-r--r--nuttx/configs/stm3220g-eval/src/up_buttons.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/nuttx/configs/stm3220g-eval/src/up_buttons.c b/nuttx/configs/stm3220g-eval/src/up_buttons.c
index 3ae268cad..091bb6216 100644
--- a/nuttx/configs/stm3220g-eval/src/up_buttons.c
+++ b/nuttx/configs/stm3220g-eval/src/up_buttons.c
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
****************************************************************************/
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* Description:
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
* buttons or up_irqbutton() may be called to register button interrupt
* handlers.
*
* After board_button_initialize() has been called, board_buttons() may be called to
@@ -146,7 +146,7 @@ uint8_t board_buttons(void)
* with each bit associated with a button. See the BUTTON_*_BIT
* definitions in board.h for the meaning of each bit.
*
* up_irqbutton() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the
* BUTTON_* definitions in board.h for the meaning of enumeration
@@ -156,7 +156,7 @@ uint8_t board_buttons(void)
************************************************************************************/
#ifdef CONFIG_ARCH_IRQBUTTONS
-xcpt_t up_irqbutton(int id, xcpt_t irqhandler)
+xcpt_t board_button_irq(int id, xcpt_t irqhandler)
{
xcpt_t oldhandler = NULL;
@@ -79,7 +79,7 @@ static const uint16_t g_buttons[NUM_BUTTONS] =
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -138,7 +138,7 @@ uint8_t board_buttons(void)
* board_button_initialize() must be called to initialize button resources. After
* that, board_buttons() may be called to collect the current state of all
- * buttons or up_irqbutton() may be called to register button interrupt
+ * buttons or board_button_irq() may be called to register button interrupt
* handlers.
*
@@ -146,7 +146,7 @@ uint8_t board_buttons(void)
* definitions in board.h for the meaning of each bit.
*
- * up_irqbutton() may be called to register an interrupt handler that will
+ * board_button_irq() may be called to register an interrupt handler that will
* be called when a button is depressed or released. The ID value is a
* button enumeration value that uniquely identifies a button resource. See the